﻿#!/usr/bin/env python3

import sys
import os
import subprocess
import shutil

# params
program_filename = r'C:\Program Files\PDF3DReportGen\PDF3DReportGen.exe'
org_state_filename = r'test.pdf3dsettings.org'

# Target
loop_num = 3

# Output PDF
output_pdfname = [r"result_suspension.pdf", 
                  r"result_brake.pdf", 
                  r"result_wheels.pdf"]

# Input Data
input_data = [r"car_v76_suspension_part_details.3ds",
              r"car_v76_disc_brake.3ds",
              r"car_v76_wheels_front.3ds"]

# Fig Name
title_name = ["図1. サスペンション部品",
              "図1. ブレーキディスク部品",
              "図1. タイヤ部品"]


# change keyword 
def change_target(infile, old_word, new_word):

  if not os.path.isfile(infile):
    print ("Error access state file : " + infile)
    sys.exit(1)

  f1 = open(infile, 'r', encoding='utf-8').read()
  f2 = open(infile, 'w', encoding='utf-8')
  f2.write(f1.replace(old_word, new_word))
  

# run
def run_batch():

  # target
  print('Starting')

  # Loop for data
  for i in range(loop_num):

    # set file
    state_filename = org_state_filename + ".tmp"
    shutil.copy(org_state_filename, state_filename)

    # change keyword (Ouput filename)
    old_name = "MY_OUTPUT_PDF"
    out_name = output_pdfname[i]
    change_target(state_filename, old_name, out_name)

    # change keyword (Input data)
    old_name = "MY_INPUT_DATA"
    in_name = input_data[i]
    change_target(state_filename, old_name, in_name)

    # change keyword (Fig name)
    old_name = "MY_TITLE"
    t_name = title_name[i]
    change_target(state_filename, old_name, t_name)

    # run command
    command_string = [program_filename, "-state", state_filename, "-silent"]

    # execute 
    try:
      print('running [%d] : %s ' % (i, command_string))
      success = subprocess.call(command_string)
      ##success = subprocess.Popen(command_string)
    except:
      # report error details
      print('ERROR: Unable to run : ', command_string)


  return


# Main program 
if __name__ == '__main__':

  # args (example)
  #argvs = sys.argv
  #argc = len(argvs)
  #if (argc != 2):
  #  print('Usage: %s data' % argvs[0])
  #  sys.exit(1)

  # run sample
  run_batch()


